/*
File: RansMessage.java
Date		Author		Changes
Aug 22 96	Lukasz Beca	Created
*/

package webwisdom.tango.messages;

import webwisdom.tango.messages.Message;
import webwisdom.tango.consts.Const;
import java.io.*;

/**
 * A class representing message RANS
 * 
 *@author Lukasz Beca
 *@see Central Server - Local Demon protocol
 **/

public class RansMessage extends Message {
  
  private int answer;
  private int AT;
  private int localUID;
  private int remoteUID;	
  private int SID;

 /**
   * Creates a new RANS message
   *@param ATpar application type
   *@param localUIDpar local user number
   *@param remoteUIDpar remote user number
   *@param SIDpar session number
   *@param answerpar answer: Const.YES or Const.NO 
   *@see Const
   **/
  

  public RansMessage(int ATpar, int localUIDpar, int remoteUIDpar, int SIDpar, int answerpar) {

   AT = ATpar;
   localUID = localUIDpar;
   remoteUID = remoteUIDpar;
   SID = SIDpar;  
   answer = answerpar;

   type = Const.RANS;
  
  }

 /**
   * Creates a new RANS message, information is read from the input stream
   *@param instream  input stream
   **/

  RansMessage(DataInputStream instream) throws IOException {
       

    AT = instream.readInt();   
    localUID = instream.readInt();   
    remoteUID = instream.readInt();    
    SID = instream.readInt();     
    answer = instream.readInt();

    type = Const.RANS;
    
  }

  /**
   * Writes RANS message to the output stream
   *@param outstream  output stream
   **/

  void send(DataOutputStream outstream) throws IOException {
  
   
    //System.out.println("Sending type " + Const.RANS);
    outstream.writeInt(Const.RANS);
    //System.out.println("Sending AT " + AT);
    outstream.writeInt(AT);
    //System.out.println("Sending localUID " + localUID);
    outstream.writeInt(localUID);
    //System.out.println("Sending remoteUID " + remoteUID);
    outstream.writeInt(remoteUID);
    //System.out.println("Sending SID " + SID);
    outstream.writeInt(SID);     
    //System.out.println("Sending answer " + answer);
    outstream.writeInt(answer);

    outstream.flush();

  }
 
  /**
   * Returns remote user number
   **/

  public int getRemoteUID() {
       
    return remoteUID;

  }  

 /**
   * Returns local user number
   **/

  public int getLocalUID() {
       
    return localUID;

  }  

 /**
   * Returns application type
   **/

  public int getAT() {
       
    return AT;

  }  
 
   /**
   * Returns session number
   **/

  public int getSID() {
   
    return SID;
  }

 /**
   * Returns answer
   **/

  public int getAnswer() {
   
    return answer;
  }
  
}

